@@ -3,6 +3,9 @@
 
 import sys
 
+# Defines where data should be downloaded and loaded
+DATA_FOLDER = 'data/'
+
 # A constant value used to avoid division by zero, zero logarithms
 # and any possible mathematical error
 EPSILON = 1e-32
